@@ -25,12 +25,13 @@ using namespace isc::data;
 using namespace isc::dhcp;
 using namespace isc::hooks;
 using namespace isc::log;
+using namespace isc::stats;
 
 namespace isc {
 namespace ha {
 
 HAImpl::HAImpl()
-    : config_(), services_(new HAServiceMapper()) {
+    : io_service_(new IOService()), config_(), services_(new HAServiceMapper()) {
 }
 
 void
@@ -39,13 +40,12 @@ HAImpl::configure(const ConstElementPtr& input_config) {
 }
 
 void
-HAImpl::startServices(const IOServicePtr& io_service,
-                      const NetworkStatePtr& network_state,
+HAImpl::startServices(const NetworkStatePtr& network_state,
                       const HAServerType& server_type) {
     auto configs = config_->getAll();
     for (auto id = 0; id < configs.size(); ++id) {
         // Create the HA service and crank up the state machine.
-        auto service = boost::make_shared<HAService>(id, io_service, network_state,
+        auto service = boost::make_shared<HAService>(id, io_service_, network_state,
                                                      configs[id], server_type);
         for (auto const& peer_config : configs[id]->getAllServersConfig()) {
             services_->map(peer_config.first, service);
@@ -53,7 +53,7 @@ HAImpl::startServices(const IOServicePtr& io_service,
     }
     // Schedule a start of the services. This ensures we begin after
     // the dust has settled and Kea MT mode has been firmly established.
-    io_service->post([&]() {
+    io_service_->post([&]() {
         for (auto const& service : services_->getAll()) {
             service->startClientAndListener();
         }
@@ -104,10 +104,8 @@ HAImpl::buffer4Receive(hooks::CalloutHandle& callout_handle) {
             .arg(ex.what());
 
         // Increase the statistics of parse failures and dropped packets.
-        isc::stats::StatsMgr::instance().addValue("pkt4-parse-failed",
-                                                  static_cast<int64_t>(1));
-        isc::stats::StatsMgr::instance().addValue("pkt4-receive-drop",
-                                                  static_cast<int64_t>(1));
+        StatsMgr::instance().addValue("pkt4-parse-failed", static_cast<int64_t>(1));
+        StatsMgr::instance().addValue("pkt4-receive-drop", static_cast<int64_t>(1));
 
 
         callout_handle.setStatus(CalloutHandle::NEXT_STEP_DROP);
@@ -154,6 +152,7 @@ HAImpl::subnet4Select(hooks::CalloutHandle& callout_handle) {
         LOG_DEBUG(ha_logger, DBGLVL_TRACE_BASIC, HA_SUBNET4_SELECT_NO_SUBNET_SELECTED)
             .arg(query4->getLabel());
         callout_handle.setStatus(CalloutHandle::NEXT_STEP_DROP);
+        StatsMgr::instance().addValue("pkt4-receive-drop", static_cast<int64_t>(1));
         return;
     }
 
@@ -169,6 +168,7 @@ HAImpl::subnet4Select(hooks::CalloutHandle& callout_handle) {
                 .arg(query4->getLabel())
                 .arg(subnet4->toText());
             callout_handle.setStatus(CalloutHandle::NEXT_STEP_DROP);
+            StatsMgr::instance().addValue("pkt4-receive-drop", static_cast<int64_t>(1));
             return;
         }
 
@@ -177,6 +177,7 @@ HAImpl::subnet4Select(hooks::CalloutHandle& callout_handle) {
             .arg(query4->getLabel())
             .arg(subnet4->toText());
         callout_handle.setStatus(CalloutHandle::NEXT_STEP_DROP);
+        StatsMgr::instance().addValue("pkt4-receive-drop", static_cast<int64_t>(1));
         return;
     }
 
@@ -187,6 +188,7 @@ HAImpl::subnet4Select(hooks::CalloutHandle& callout_handle) {
             .arg(query4->getLabel())
             .arg(server_name);
         callout_handle.setStatus(CalloutHandle::NEXT_STEP_DROP);
+        StatsMgr::instance().addValue("pkt4-receive-drop", static_cast<int64_t>(1));
         return;
     }
 
@@ -366,10 +368,8 @@ HAImpl::buffer6Receive(hooks::CalloutHandle& callout_handle) {
             .arg(ex.what());
 
         // Increase the statistics of parse failures and dropped packets.
-        isc::stats::StatsMgr::instance().addValue("pkt6-parse-failed",
-                                                  static_cast<int64_t>(1));
-        isc::stats::StatsMgr::instance().addValue("pkt6-receive-drop",
-                                                  static_cast<int64_t>(1));
+        StatsMgr::instance().addValue("pkt6-parse-failed", static_cast<int64_t>(1));
+        StatsMgr::instance().addValue("pkt6-receive-drop", static_cast<int64_t>(1));
 
 
         callout_handle.setStatus(CalloutHandle::NEXT_STEP_DROP);
@@ -416,6 +416,7 @@ HAImpl::subnet6Select(hooks::CalloutHandle& callout_handle) {
         LOG_DEBUG(ha_logger, DBGLVL_TRACE_BASIC, HA_SUBNET6_SELECT_NO_SUBNET_SELECTED)
             .arg(query6->getLabel());
         callout_handle.setStatus(CalloutHandle::NEXT_STEP_DROP);
+        StatsMgr::instance().addValue("pkt6-receive-drop", static_cast<int64_t>(1));
         return;
     }
 
@@ -431,6 +432,7 @@ HAImpl::subnet6Select(hooks::CalloutHandle& callout_handle) {
                 .arg(query6->getLabel())
                 .arg(subnet6->toText());
             callout_handle.setStatus(CalloutHandle::NEXT_STEP_DROP);
+            StatsMgr::instance().addValue("pkt6-receive-drop", static_cast<int64_t>(1));
             return;
         }
 
@@ -439,6 +441,7 @@ HAImpl::subnet6Select(hooks::CalloutHandle& callout_handle) {
             .arg(query6->getLabel())
             .arg(subnet6->toText());
         callout_handle.setStatus(CalloutHandle::NEXT_STEP_DROP);
+        StatsMgr::instance().addValue("pkt6-receive-drop", static_cast<int64_t>(1));
         return;
     }
 
@@ -449,6 +452,7 @@ HAImpl::subnet6Select(hooks::CalloutHandle& callout_handle) {
             .arg(query6->getLabel())
             .arg(server_name);
         callout_handle.setStatus(CalloutHandle::NEXT_STEP_DROP);
+        StatsMgr::instance().addValue("pkt6-receive-drop", static_cast<int64_t>(1));
         return;
     }
 
@@ -855,15 +859,24 @@ HAImpl::syncCompleteNotifyHandler(hooks::CalloutHandle& callout_handle) {
     static_cast<void>(parseCommand(args, command));
 
     HAServicePtr service;
-    auto origin_value = NetworkState::HA_REMOTE_COMMAND+1;
+    auto origin_id_value = NetworkState::HA_REMOTE_COMMAND+1;
     try {
         if (args) {
+            auto origin_id = args->get("origin-id");
             auto origin = args->get("origin");
-            if (origin) {
+            // The origin-id is a new parameter replacing the origin. However, some versions
+            // of Kea may still send the origin parameter instead.
+            if (origin_id) {
+                if (origin_id->getType() != Element::integer) {
+                    isc_throw(BadValue, "'origin-id' must be an integer in the 'ha-sync-complete-notify' command");
+                }
+                origin_id_value = origin_id->intValue();
+
+            } else if (origin) {
                 if (origin->getType() != Element::integer) {
                     isc_throw(BadValue, "'origin' must be an integer in the 'ha-sync-complete-notify' command");
                 }
-                origin_value = origin->intValue();
+                origin_id_value = origin->intValue();
             }
         }
 
@@ -877,7 +890,7 @@ HAImpl::syncCompleteNotifyHandler(hooks::CalloutHandle& callout_handle) {
         return;
     }
 
-    ConstElementPtr response = service->processSyncCompleteNotify(origin_value);
+    ConstElementPtr response = service->processSyncCompleteNotify(origin_id_value);
     callout_handle.setArgument("response", response);
 }
 
