@@ -31,12 +31,14 @@
 #include <iterator>
 #include <vector>
 
-using namespace boost::asio::ip;
-using namespace boost::asio;
 using namespace isc::asiolink;
 using namespace isc::dns;
 using namespace isc::util;
+
+using namespace boost::asio;
+using namespace boost::asio::ip;
 using namespace std;
+
 namespace ph = std::placeholders;
 
 namespace isc {
@@ -155,11 +157,7 @@ public:
     virtual ~IOFetchTest() {
         shutdown_ = true;
         timer_.cancel();
-        service_->restart();
-        try {
-            service_->poll();
-        } catch (...) {
-        }
+        service_->stopAndPoll();
     }
 
     /// \brief UDP Response handler (the "remote UDP DNS server")
@@ -760,5 +758,5 @@ TEST_F(IOFetchTest, TcpSendReceive8192ShortSend) {
 }
 
 
-} // namespace asiodns
-} // namespace isc
+}  // namespace asiodns
+}  // namespace isc
