@@ -1,4 +1,4 @@
-// Copyright (C) 2012-2025 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2012-2024 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -21,25 +21,20 @@ namespace dhcp {
 
 const size_t CfgMgr::CONFIG_LIST_SIZE = 10;
 
-CfgMgr::CfgMgr()
-    : data_dir_checker_(new file::PathChecker(DHCP_DATA_DIR, "KEA_DHCP_DATA_DIR")),
-      d2_client_mgr_(), family_(AF_INET) {
-}
-
 CfgMgr&
 CfgMgr::instance() {
     static CfgMgr cfg_mgr;
     return (cfg_mgr);
 }
 
-std::string
-CfgMgr::getDataDir(bool reset /* = false */, const std::string explicit_path /* = "" */) {
-    return (data_dir_checker_->getPath(reset, explicit_path));
+Optional<std::string>
+CfgMgr::getDataDir() const {
+    return (datadir_);
 }
 
-std::string
-CfgMgr::validatePath(const std::string data_path, bool enforce_path /* = true */) const {
-    return (data_dir_checker_->validatePath(data_path, enforce_path));
+void
+CfgMgr::setDataDir(const std::string& datadir, bool unspecified) {
+    datadir_ = Optional<std::string>(datadir, unspecified);
 }
 
 void
@@ -48,7 +43,7 @@ CfgMgr::setD2ClientConfig(D2ClientConfigPtr& new_config) {
     // Note that D2ClientMgr::setD2Config() actually attempts to apply the
     // configuration by stopping its sender and opening a new one and so
     // forth per the new configuration.
-    d2_client_mgr_.setD2ClientConfig(new_config);
+    d2_client_mgr_->setD2ClientConfig(new_config);
 
     // Manager will throw if the set fails, if it succeeds
     // we'll update our SrvConfig, configuration_, with the D2ClientConfig
@@ -59,17 +54,17 @@ CfgMgr::setD2ClientConfig(D2ClientConfigPtr& new_config) {
 
 bool
 CfgMgr::ddnsEnabled() {
-    return (d2_client_mgr_.ddnsEnabled());
+    return (d2_client_mgr_->ddnsEnabled());
 }
 
 const D2ClientConfigPtr&
 CfgMgr::getD2ClientConfig() const {
-    return (d2_client_mgr_.getD2ClientConfig());
+    return (d2_client_mgr_->getD2ClientConfig());
 }
 
 D2ClientMgr&
 CfgMgr::getD2ClientMgr() {
-    return (d2_client_mgr_);
+    return (*d2_client_mgr_);
 }
 
 void
@@ -224,5 +219,15 @@ CfgMgr::mergeIntoCfg(const SrvConfigPtr& target_config, const uint32_t seq) {
     }
 }
 
+CfgMgr::CfgMgr()
+    : datadir_(DHCP_DATA_DIR, true), d2_client_mgr_(new D2ClientMgr()), family_(AF_INET) {
+    // DHCP_DATA_DIR must be set set with -DDHCP_DATA_DIR="..." in Makefile.am
+    // Note: the definition of DHCP_DATA_DIR needs to include quotation marks
+    // See AM_CPPFLAGS definition in Makefile.am
+}
+
+CfgMgr::~CfgMgr() {
+}
+
 } // end of isc::dhcp namespace
 } // end of isc namespace
