@@ -1,4 +1,4 @@
-// Copyright (C) 2013-2020 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2013-2023 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -141,13 +141,14 @@ public:
     {}
 
     /// Public methods that call protected methods on the superclass.
+    using LibraryManager::unloadLibrary;
     using LibraryManager::openLibrary;
     using LibraryManager::closeLibrary;
     using LibraryManager::checkVersion;
     using LibraryManager::checkMultiThreadingCompatible;
     using LibraryManager::registerStandardCallouts;
     using LibraryManager::runLoad;
-    using LibraryManager::runUnload;
+    using LibraryManager::prepareUnloadLibrary;
 };
 
 
@@ -257,11 +258,10 @@ TEST_F(LibraryManagerTest, NoMultiThreadingCompatible) {
     EXPECT_TRUE(lib_manager.openLibrary());
 
     // Not multi-threading compatible: does not matter without MT.
-    EXPECT_TRUE(lib_manager.checkMultiThreadingCompatible());
+    EXPECT_TRUE(lib_manager.checkMultiThreadingCompatible(false));
 
     // Not multi-threading compatible: does matter with MT.
-    MultiThreadingMgr::instance().setMode(true);
-    EXPECT_FALSE(lib_manager.checkMultiThreadingCompatible());
+    EXPECT_FALSE(lib_manager.checkMultiThreadingCompatible(true));
 
     // Tidy up.
     EXPECT_TRUE(lib_manager.closeLibrary());
@@ -278,11 +278,10 @@ TEST_F(LibraryManagerTest, multiThreadingNotCompatible) {
     EXPECT_TRUE(lib_manager.openLibrary());
 
     // Not multi-threading compatible: does not matter without MT.
-    EXPECT_TRUE(lib_manager.checkMultiThreadingCompatible());
+    EXPECT_TRUE(lib_manager.checkMultiThreadingCompatible(false));
 
     // Not multi-threading compatible: does matter with MT.
-    MultiThreadingMgr::instance().setMode(true);
-    EXPECT_FALSE(lib_manager.checkMultiThreadingCompatible());
+    EXPECT_FALSE(lib_manager.checkMultiThreadingCompatible(true));
 
     // Tidy up.
     EXPECT_TRUE(lib_manager.closeLibrary());
@@ -299,11 +298,10 @@ TEST_F(LibraryManagerTest, multiThreadingCompatible) {
     EXPECT_TRUE(lib_manager.openLibrary());
 
     // Multi-threading compatible: does not matter without MT.
-    EXPECT_TRUE(lib_manager.checkMultiThreadingCompatible());
+    EXPECT_TRUE(lib_manager.checkMultiThreadingCompatible(false));
 
     // Multi-threading compatible: does matter with MT.
-    MultiThreadingMgr::instance().setMode(true);
-    EXPECT_TRUE(lib_manager.checkMultiThreadingCompatible());
+    EXPECT_TRUE(lib_manager.checkMultiThreadingCompatible(true));
 
     // Tidy up.
     EXPECT_TRUE(lib_manager.closeLibrary());
@@ -320,11 +318,10 @@ TEST_F(LibraryManagerTest, multiThreadingCompatibleException) {
     EXPECT_TRUE(lib_manager.openLibrary());
 
     // Throw exception: does not matter without MT.
-    EXPECT_TRUE(lib_manager.checkMultiThreadingCompatible());
+    EXPECT_TRUE(lib_manager.checkMultiThreadingCompatible(false));
 
     // Throw exception: does matter with MT.
-    MultiThreadingMgr::instance().setMode(true);
-    EXPECT_FALSE(lib_manager.checkMultiThreadingCompatible());
+    EXPECT_FALSE(lib_manager.checkMultiThreadingCompatible(true));
 
     // Tidy up.
     EXPECT_TRUE(lib_manager.closeLibrary());
@@ -337,7 +334,7 @@ TEST_F(LibraryManagerTest, RegisterStandardCallouts) {
     // Load the only library, specifying the index of 0 as it's the only
     // library.  This should load all callouts.
     PublicLibraryManager lib_manager(std::string(BASIC_CALLOUT_LIBRARY),
-                               0, callout_manager_);
+                                     0, callout_manager_);
     EXPECT_TRUE(lib_manager.openLibrary());
 
     // Check the version of the library.
@@ -455,7 +452,7 @@ TEST_F(LibraryManagerTest, CheckNoUnload) {
     EXPECT_TRUE(lib_manager.openLibrary());
 
     // Check that no unload function returns true.
-    EXPECT_TRUE(lib_manager.runUnload());
+    EXPECT_TRUE(lib_manager.prepareUnloadLibrary());
 
     // Tidy up
     EXPECT_TRUE(lib_manager.closeLibrary());
@@ -472,7 +469,7 @@ TEST_F(LibraryManagerTest, CheckUnloadError) {
     EXPECT_TRUE(lib_manager.openLibrary());
 
     // Check that unload function returning an error returns false.
-    EXPECT_FALSE(lib_manager.runUnload());
+    EXPECT_FALSE(lib_manager.prepareUnloadLibrary());
 
     // Tidy up
     EXPECT_TRUE(lib_manager.closeLibrary());
@@ -489,7 +486,7 @@ TEST_F(LibraryManagerTest, CheckUnloadException) {
     EXPECT_TRUE(lib_manager.openLibrary());
 
     // Check that we detect that the unload function throws an exception.
-    EXPECT_FALSE(lib_manager.runUnload());
+    EXPECT_FALSE(lib_manager.prepareUnloadLibrary());
 
     // Tidy up
     EXPECT_TRUE(lib_manager.closeLibrary());
@@ -512,7 +509,7 @@ TEST_F(LibraryManagerTest, CheckUnload) {
     EXPECT_FALSE(markerFilePresent());
 
     // Check that unload function runs and returns a success
-    EXPECT_TRUE(lib_manager.runUnload());
+    EXPECT_TRUE(lib_manager.prepareUnloadLibrary());
 
     // Check that the marker file was created.
     EXPECT_TRUE(markerFilePresent());
@@ -531,7 +528,7 @@ TEST_F(LibraryManagerTest, LibUnload) {
     // Load the only library, specifying the index of 0 as it's the only
     // library.  This should load all callouts.
     PublicLibraryManager lib_manager(std::string(LOAD_CALLOUT_LIBRARY),
-                               0, callout_manager_);
+                                     0, callout_manager_);
     EXPECT_TRUE(lib_manager.openLibrary());
 
     // Check the version of the library.
@@ -603,8 +600,8 @@ TEST_F(LibraryManagerTest, LoadLibraryWrongVersion) {
 // Check that the full loadLibrary call works.
 
 TEST_F(LibraryManagerTest, LoadLibrary) {
-    LibraryManager lib_manager(std::string(FULL_CALLOUT_LIBRARY), 0,
-                                           callout_manager_);
+    PublicLibraryManager lib_manager(std::string(FULL_CALLOUT_LIBRARY), 0,
+                                     callout_manager_);
     EXPECT_TRUE(lib_manager.loadLibrary());
 
     // Now execute the callouts in the order expected.  The library performs
@@ -631,28 +628,28 @@ TEST_F(LibraryManagerTest, LoadLibrary) {
 
 TEST_F(LibraryManagerTest, LoadMultipleLibraries) {
     // Load a library with all framework functions.
-    LibraryManager lib_manager_1(std::string(FULL_CALLOUT_LIBRARY), 0,
-                                 callout_manager_);
+    PublicLibraryManager lib_manager_1(std::string(FULL_CALLOUT_LIBRARY),
+                                       0, callout_manager_);
     EXPECT_TRUE(lib_manager_1.loadLibrary());
 
     // Attempt to load a library with no version() function.  We should detect
     // this and not end up calling the function from the already loaded
     // library.
-    LibraryManager lib_manager_2(std::string(NO_VERSION_LIBRARY), 1,
-                                 callout_manager_);
+    PublicLibraryManager lib_manager_2(std::string(NO_VERSION_LIBRARY),
+                                       1, callout_manager_);
     EXPECT_FALSE(lib_manager_2.loadLibrary());
 
     // Attempt to load the library with an incorrect version.  This should
     // be detected.
-    LibraryManager lib_manager_3(std::string(INCORRECT_VERSION_LIBRARY), 1,
-                                 callout_manager_);
+    PublicLibraryManager lib_manager_3(std::string(INCORRECT_VERSION_LIBRARY),
+                                       1, callout_manager_);
     EXPECT_FALSE(lib_manager_3.loadLibrary());
 
     // Load the basic callout library.  This only has standard callouts so,
     // if the first library's load() function gets called, some callouts
     // will be registered twice and lead to incorrect results.
-    LibraryManager lib_manager_4(std::string(BASIC_CALLOUT_LIBRARY), 1,
-                                 callout_manager_);
+    PublicLibraryManager lib_manager_4(std::string(BASIC_CALLOUT_LIBRARY),
+                                       1, callout_manager_);
     EXPECT_TRUE(lib_manager_4.loadLibrary());
 
     // Execute the callouts.  The first library implements the calculation.
@@ -694,26 +691,24 @@ TEST_F(LibraryManagerTest, validateLibraries) {
     EXPECT_TRUE(LibraryManager::validateLibrary(UNLOAD_CALLOUT_LIBRARY));
     EXPECT_TRUE(LibraryManager::validateLibrary(CALLOUT_PARAMS_LIBRARY));
 
-    MultiThreadingMgr::instance().setMode(true);
-
-    EXPECT_FALSE(LibraryManager::validateLibrary(BASIC_CALLOUT_LIBRARY));
-    EXPECT_TRUE(LibraryManager::validateLibrary(FULL_CALLOUT_LIBRARY));
-    EXPECT_FALSE(LibraryManager::validateLibrary(FRAMEWORK_EXCEPTION_LIBRARY));
-    EXPECT_FALSE(LibraryManager::validateLibrary(INCORRECT_VERSION_LIBRARY));
-    EXPECT_FALSE(LibraryManager::validateLibrary(LOAD_CALLOUT_LIBRARY));
-    EXPECT_FALSE(LibraryManager::validateLibrary(LOAD_ERROR_CALLOUT_LIBRARY));
-    EXPECT_FALSE(LibraryManager::validateLibrary(NOT_PRESENT_LIBRARY));
-    EXPECT_FALSE(LibraryManager::validateLibrary(NO_VERSION_LIBRARY));
-    EXPECT_FALSE(LibraryManager::validateLibrary(UNLOAD_CALLOUT_LIBRARY));
-    EXPECT_FALSE(LibraryManager::validateLibrary(CALLOUT_PARAMS_LIBRARY));
+    EXPECT_FALSE(LibraryManager::validateLibrary(BASIC_CALLOUT_LIBRARY, true));
+    EXPECT_TRUE(LibraryManager::validateLibrary(FULL_CALLOUT_LIBRARY, true));
+    EXPECT_FALSE(LibraryManager::validateLibrary(FRAMEWORK_EXCEPTION_LIBRARY, true));
+    EXPECT_FALSE(LibraryManager::validateLibrary(INCORRECT_VERSION_LIBRARY, true));
+    EXPECT_FALSE(LibraryManager::validateLibrary(LOAD_CALLOUT_LIBRARY, true));
+    EXPECT_FALSE(LibraryManager::validateLibrary(LOAD_ERROR_CALLOUT_LIBRARY, true));
+    EXPECT_FALSE(LibraryManager::validateLibrary(NOT_PRESENT_LIBRARY, true));
+    EXPECT_FALSE(LibraryManager::validateLibrary(NO_VERSION_LIBRARY, true));
+    EXPECT_FALSE(LibraryManager::validateLibrary(UNLOAD_CALLOUT_LIBRARY, true));
+    EXPECT_FALSE(LibraryManager::validateLibrary(CALLOUT_PARAMS_LIBRARY, true));
 }
 
 // Check that log messages are properly registered and unregistered.
 
 TEST_F(LibraryManagerTest, libraryLoggerSetup) {
     // Load a library with all framework functions.
-    LibraryManager lib_manager(std::string(BASIC_CALLOUT_LIBRARY), 0,
-                               callout_manager_);
+    PublicLibraryManager lib_manager(std::string(BASIC_CALLOUT_LIBRARY),
+                                     0, callout_manager_);
     EXPECT_TRUE(lib_manager.loadLibrary());
 
     // After loading the library, the global logging dictionary should
@@ -730,8 +725,11 @@ TEST_F(LibraryManagerTest, libraryLoggerSetup) {
 
     // After unloading the library, the messages should be unregistered.
     EXPECT_TRUE(lib_manager.unloadLibrary());
+    // The musl libc does not implement dlclose
+#ifndef LIBC_MUSL
     EXPECT_TRUE(dict->getText("BCL_LOAD_START").empty());
     EXPECT_TRUE(dict->getText("BCL_LOAD_END").empty());
+#endif
 }
 
 } // Anonymous namespace
